@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def disconnect(vmanage, nmsId):
     """
     disconnect from mpd controller
@@ -14,8 +11,8 @@ def disconnect(vmanage, nmsId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/mdp/disconnect/{nmsId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/mdp/disconnect/{nmsId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def offboard(vmanage, nmsId):
@@ -31,6 +28,6 @@ def offboard(vmanage, nmsId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/mdp/onboard/{nmsId}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/mdp/onboard/{nmsId}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
