@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def get(vmanage, uuid):
     """
     Get reverse proxy IP/Port mappings for controller
@@ -14,8 +11,8 @@ def get(vmanage, uuid):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/system/reverseproxy/{uuid}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/system/reverseproxy/{uuid}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def create(vmanage, mapping, uuid):
     """
@@ -31,6 +28,6 @@ def create(vmanage, mapping, uuid):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/system/reverseproxy/{uuid}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, mapping)
+    endpoint = f"dataservice/system/reverseproxy/{uuid}"
+    response = vmanage.apiCall("POST", endpoint, mapping)
     return response
