@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def invalidateDevice(vmanage, devInfo):
     """
     invalidate the device
@@ -14,8 +11,8 @@ def invalidateDevice(vmanage, devInfo):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/certificate/device/invalidate"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, devInfo)
+    endpoint = f"dataservice/certificate/device/invalidate"
+    response = vmanage.apiCall("POST", endpoint, devInfo)
     return response
 def stageDevice(vmanage, devInfo):
     """
@@ -30,8 +27,8 @@ def stageDevice(vmanage, devInfo):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/certificate/device/stage"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, devInfo)
+    endpoint = f"dataservice/certificate/device/stage"
+    response = vmanage.apiCall("POST", endpoint, devInfo)
     return response
 def createAdminTech(vmanage, request):
     """
@@ -46,8 +43,8 @@ def createAdminTech(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/admintech"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, request)
+    endpoint = f"dataservice/device/tools/admintech"
+    response = vmanage.apiCall("POST", endpoint, request)
     return response
 def copyAdminTechOnDevice(vmanage, request):
     """
@@ -62,8 +59,8 @@ def copyAdminTechOnDevice(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/admintech/copy"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, request)
+    endpoint = f"dataservice/device/tools/admintech/copy"
+    response = vmanage.apiCall("POST", endpoint, request)
     return response
 def deleteAdminTechOnDevice(vmanage, request):
     """
@@ -78,8 +75,8 @@ def deleteAdminTechOnDevice(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/admintech/delete"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint, request)
+    endpoint = f"dataservice/device/tools/admintech/delete"
+    response = vmanage.apiCall("DELETE", endpoint, request)
     return response
 def downloadAdminTechFile(vmanage, filename):
     """
@@ -94,8 +91,8 @@ def downloadAdminTechFile(vmanage, filename):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/admintech/download/{filename}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/tools/admintech/download/{filename}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def deleteAdminTechFile(vmanage, requestID):
     """
@@ -110,8 +107,8 @@ def deleteAdminTechFile(vmanage, requestID):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/admintech/{requestID}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/device/tools/admintech/{requestID}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
 def listAdminTechsOnDevice(vmanage, request):
     """
@@ -126,8 +123,8 @@ def listAdminTechsOnDevice(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/admintechlist"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, request)
+    endpoint = f"dataservice/device/tools/admintechlist"
+    response = vmanage.apiCall("POST", endpoint, request)
     return response
 def listAdminTechs(vmanage):
     """
@@ -141,8 +138,8 @@ def listAdminTechs(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/admintechs"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/tools/admintechs"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getInProgressCount(vmanage):
     """
@@ -156,8 +153,8 @@ def getInProgressCount(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/admintechs/inprogress"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/tools/admintechs/inprogress"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def factoryReset(vmanage, payload):
     """
@@ -172,8 +169,8 @@ def factoryReset(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/factoryreset"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/tools/factoryreset"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 def npingDevice(vmanage, npingparameter, deviceIP):
     """
@@ -189,8 +186,8 @@ def npingDevice(vmanage, npingparameter, deviceIP):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/nping/{deviceIP}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, npingparameter)
+    endpoint = f"dataservice/device/tools/nping/{deviceIP}"
+    response = vmanage.apiCall("POST", endpoint, npingparameter)
     return response
 def pingDevice(vmanage, pingparameter, deviceIP):
     """
@@ -206,8 +203,8 @@ def pingDevice(vmanage, pingparameter, deviceIP):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/ping/{deviceIP}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, pingparameter)
+    endpoint = f"dataservice/device/tools/ping/{deviceIP}"
+    response = vmanage.apiCall("POST", endpoint, pingparameter)
     return response
 def processPortHopColor(vmanage, deviceporthopcolor, deviceIP):
     """
@@ -223,8 +220,8 @@ def processPortHopColor(vmanage, deviceporthopcolor, deviceIP):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/porthopcolor/{deviceIP}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, deviceporthopcolor)
+    endpoint = f"dataservice/device/tools/porthopcolor/{deviceIP}"
+    response = vmanage.apiCall("POST", endpoint, deviceporthopcolor)
     return response
 def processInterfaceReset(vmanage, deviceinterface, deviceIP):
     """
@@ -240,8 +237,8 @@ def processInterfaceReset(vmanage, deviceinterface, deviceIP):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/reset/interface/{deviceIP}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, deviceinterface)
+    endpoint = f"dataservice/device/tools/reset/interface/{deviceIP}"
+    response = vmanage.apiCall("POST", endpoint, deviceinterface)
     return response
 def processResetUser(vmanage, deviceuserreset, deviceIP):
     """
@@ -257,8 +254,8 @@ def processResetUser(vmanage, deviceuserreset, deviceIP):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/resetuser/{deviceIP}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, deviceuserreset)
+    endpoint = f"dataservice/device/tools/resetuser/{deviceIP}"
+    response = vmanage.apiCall("POST", endpoint, deviceuserreset)
     return response
 def servicePath(vmanage, servicepathparameter, deviceIP):
     """
@@ -274,8 +271,8 @@ def servicePath(vmanage, servicepathparameter, deviceIP):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/servicepath/{deviceIP}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, servicepathparameter)
+    endpoint = f"dataservice/device/tools/servicepath/{deviceIP}"
+    response = vmanage.apiCall("POST", endpoint, servicepathparameter)
     return response
 def tracerouteDevice(vmanage, tracerouteparameter, deviceIP):
     """
@@ -291,8 +288,8 @@ def tracerouteDevice(vmanage, tracerouteparameter, deviceIP):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/traceroute/{deviceIP}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, tracerouteparameter)
+    endpoint = f"dataservice/device/tools/traceroute/{deviceIP}"
+    response = vmanage.apiCall("POST", endpoint, tracerouteparameter)
     return response
 def tunnelPath(vmanage, tunnelpathparameter, deviceIP):
     """
@@ -308,8 +305,8 @@ def tunnelPath(vmanage, tunnelpathparameter, deviceIP):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tools/tunnelpath/{deviceIP}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, tunnelpathparameter)
+    endpoint = f"dataservice/device/tools/tunnelpath/{deviceIP}"
+    response = vmanage.apiCall("POST", endpoint, tunnelpathparameter)
     return response
 def getControlConnections(vmanage, uuid):
     """
@@ -324,8 +321,8 @@ def getControlConnections(vmanage, uuid):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/troubleshooting/control/{uuid}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/troubleshooting/control/{uuid}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getDeviceConfiguration(vmanage, uuid):
     """
@@ -340,6 +337,6 @@ def getDeviceConfiguration(vmanage, uuid):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/troubleshooting/devicebringup?uuid={uuid}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/troubleshooting/devicebringup?uuid={uuid}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
