@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getAllKeys(vmanage):
     """
     Get keys from Umbrella
@@ -13,8 +10,8 @@ def getAllKeys(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/umbrella/getkeys"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/umbrella/getkeys"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getManagementKeys(vmanage):
     """
@@ -28,8 +25,8 @@ def getManagementKeys(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/umbrella/getkeys/management"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/umbrella/getkeys/management"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getNetworkKeys(vmanage):
     """
@@ -43,8 +40,8 @@ def getNetworkKeys(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/umbrella/getkeys/networkdevices"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/umbrella/getkeys/networkdevices"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getReportingKeys(vmanage):
     """
@@ -58,6 +55,6 @@ def getReportingKeys(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/umbrella/getkeys/reporting"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/umbrella/getkeys/reporting"
+    response = vmanage.apiCall("GET", endpoint)
     return response
